@@ -15,16 +15,24 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, Handy
+from gi.repository import Adw, Gtk
 
 
 @Gtk.Template(resource_path="/dev/tchx84/Portfolio/place.ui")
-class PortfolioPlace(Handy.ActionRow):
+class PortfolioPlace(Adw.ActionRow):
     __gtype_name__ = "PortfolioPlace"
 
+    icon = Gtk.Template.Child()
     eject = Gtk.Template.Child()
     mount = None
     path = ""
     uuid = ""
     encrypted = None
     device = None
+
+    def set_custom_icon_name(self, name):
+        self.icon.set_from_icon_name(name)
+
+    def set_subtitle_sately(self, subtitle):
+        if subtitle is not None:
+            self.set_subtitle(subtitle)
